import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table,BottomBtn} from '@/components/Common-Library'
import Api from '@/service/api'
import mBrtfee from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import { Col, Row } from 'antd'
import Business from '@/views/Public/Business'



const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class BrtfeeScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'brtfee'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mBrtfee()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('brtfee/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">
            	<Business wrappedComponentRef={ref => (this.com = ref)} page={this} extra={this.props.extra} steps={this.props.steps} model={this.model} />

				{/* 第1行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="参考号" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("ownref1")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="到日期" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第2行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="信用证余额" trn="brtfee" />	
								</Col>
								<Col span={6}>
									<InputItem InputProps={bind("opn11_cur")}  maxLength={3}  desp="Currency" path="/lidgrp/cbs/opn1/cur" />
								</Col>
								<Col span={7} offset={1}>
									<InputItem InputProps={bind("opn11_amt")}   desp="Balance" path="/lidgrp/cbs/opn1/amt" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据参考号" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Own Reference BR Number" path="/brdgrp/rec/ownref" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第3行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* <Label itext="Name of Bill Contract" trn="brtfee" />	 */}
									<Label itext="N O B C" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("nam")}  maxLength={40}  desp="Name of Bill Contract" path="/brdgrp/rec/nam" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据金额" trn="brtfee" />	
								</Col>
								<Col span={6}>
								<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/max/cur"/>
								</Col>
								<Col span={7} offset={1}>
								<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/brdgrp/cbs/max/amt" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第4行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
								<Label itext="申请人" trn="brtfee" />	
								</Col>
							</Row>
						</Col>
						
					</Row>
				{/* 第4行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="参考号" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/apl/pts/ref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据余额" trn="brtfee" />	
								</Col>
								<Col span={6}>
									<InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/brdgrp/cbs/opn1/cur" />
								</Col>
								<Col span={7} offset={1}>
									<InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/brdgrp/cbs/opn1/amt" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第5行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="客户英文名称" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/apl/pts/nam" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="到单日期" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<DatePickerItem InputProps={bind("rcvdat")}  desp="Date of Receipt of Documents" path="/brdgrp/rec/rcvdat" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第6行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="寄单日期" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<DatePickerItem InputProps={bind("advdat")}  desp="Date of Advice of Payment" path="/brdgrp/rec/advdat" />
								</Col>
							</Row>
						</Col>
						
					</Row>
					{/* 第7行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="受益人" trn="brtfee" />	
								</Col>
							</Row>
						</Col>
						
					</Row>
					{/* 第8行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="参考号" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/ben/pts/ref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="到期日" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<DatePickerItem InputProps={bind("matdat")}  desp="Maturity Date" path="/brdgrp/rec/matdat" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第9行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="客户英文名称" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/ben/pts/nam" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据类型" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("docflg")}   desp="Usance, Sight or Mixed" path="/brdgrp/rec/docflg"/>
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第10行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="交单行" trn="brtfee" />	
								</Col>
							</Row>
						</Col>
						
					</Row>
					{/* 第11行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="参考号" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/prb/pts/ref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据承付状态" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("docsta")} code={CodeTable.docsta}  desp="Document Set Status" path="/brdgrp/rec/docsta"/>
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第12行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="客户英文名称" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/prb/pts/nam" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第13行 */}
				<Row>
					<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* <Label itext="Internal Transfer Y/N" trn="brtfee" />	 */}
									<Label itext="Int Tf Y/N" trn="brtfee" />	
								</Col>
								<Col span={14}>
									<CheckboxItem InputProps={bind("intmbu_umbflg")}  desp="Internal Transfer Y/N" path="/xxtfee/intmbu/umbflg" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Business Sector" trn="brtfee" />		
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("intmbu_othbussec")} code={CodeTable.bustxt}  desp="Business Sector" path="/xxtfee/intmbu/othbussec"/>
								</Col>
							</Row>
						</Col>
					</Row>
			
                	<BottomBtn _this={this} />

		</div>
		)
	}
}
