import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table,BottomBtn} from '@/components/Common-Library'
import Api from '@/service/api'
import mBrtset from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import Business from '@/views/Public/Business'
import Ptspta2 from '@/views/Public/Ptspta2'
import {Row,Col} from 'antd'

const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class BrtsetScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'brtset'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mBrtset()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('brtset/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    

    onPrbp_sel= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('brtset/prbp_sel',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">
				{/* brtp/brthdr */}
				{/* 第1行 */}
				<Business wrappedComponentRef={ref => (this.com = ref)} page={this} extra={this.props.extra} steps={this.props.steps} model={this.model} />

				<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="信用证编号" trn="brtset" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("ownref1")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="信用证余额" trn="brtset" />	
								</Col>
								<Col span={6}>
									<SelectItem InputProps={bind("opn11_cur")} code={CodeTable.cur}  desp="Currency" path="/lidgrp/cbs/opn1/cur"/>
								</Col>
								<Col span={7} offset={1}>
									<InputItem InputProps={bind("opn11_amt")}   desp="Balance" path="/lidgrp/cbs/opn1/amt" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第2行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据参考号" trn="brtset" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Own Reference BR Number" path="/brdgrp/rec/ownref" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* <Label itext="Name of Bill Contract" trn="brtset" />	 */}
									<Label itext="N O B C" trn="brtset" />
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("nam")}  maxLength={40}  desp="Name of Bill Contract" path="/brdgrp/rec/nam" />
								</Col>
								
							</Row>
						</Col>
					</Row>
					{/* 第3行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="申请人" trn="brtset" />	
								</Col>
							</Row>
							
						</Col>
					
					</Row>
					{/* 第4行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="编号" trn="brtset" />	
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/apl/pts/ref" />
								</Col>
							</Row>
							
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="到期日" trn="brtset" />	
								</Col>
								<Col span={14}>
									<DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
								</Col>
							</Row>
							
						</Col>
                    </Row>
						{/* 第5行 */}
						<Row>
							<Col span={12}>
								<Row className="row">
									<Col span={5} offset={2}>
										<Label itext="客户英文名称" trn="brtset" />	
									</Col>
									<Col span={14}>
										<InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/apl/pts/nam" />
									</Col>
								</Row>
								
							</Col>
							<Col span={12}>
								<Row className="row">
									<Col span={5} offset={2}>
										<Label itext="单据金额" trn="brtset" />	
									</Col>
									<Col span={6}>
										<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/max/cur"/>
									</Col>
									<Col span={7} offset={1}>
										<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/brdgrp/cbs/max/amt" />
									</Col>
								</Row>
							</Col>
						</Row>
						{/* 第6行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									 <Label itext="受益人" trn="brtset" />	
								</Col>
							</Row>
						</Col>
                    </Row>
                    {/* 第7行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="编号" trn="brtset" />	
								</Col>
                                <Col span={14} >
                                 <InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/ben/pts/ref" />
								</Col>
							</Row>
						</Col>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据余额" trn="brtset" />	
								</Col>
                                <Col span={6} >
                                     <InputItem InputProps={bind("opn1_cur")}  maxLength={3}  desp="Currency" path="/brdgrp/cbs/opn1/cur" />
								</Col>
                                <Col span={7}  offset={1}>
                                     <InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/brdgrp/cbs/opn1/amt" />
								</Col>
							</Row>
						</Col>
                    </Row>
                    {/* 第8行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="客户英文名称" trn="brtset" />	
								</Col>
                                <Col span={14} >
                                    <InputItem InputProps={bind("pts1_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/ben/pts/nam" />
								</Col>
							</Row>
						</Col>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="到单日期" trn="brtset" />	
								</Col>
                                <Col span={14} >
                                    <DatePickerItem InputProps={bind("rcvdat")}  desp="Date of Receipt of Documents" path="/brdgrp/rec/rcvdat" />
								</Col>
							</Row>
						</Col>
                    </Row>
                    {/* 第9行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="通知到单日期" trn="brtset" />	
								</Col>
                                <Col span={14} >
                                    <DatePickerItem InputProps={bind("advdat")}  desp="Date of Advice of Payment" path="/brdgrp/rec/advdat" />
								</Col>
							</Row>
						</Col>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="远期单据到期日" trn="brtset" />	
								</Col>
                                <Col span={14} >
                                     <DatePickerItem InputProps={bind("matdat")}  desp="Maturity Date" path="/brdgrp/rec/matdat" />
								</Col>
							</Row>
						</Col>
                    </Row>
                    {/* 第10行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="交单行" trn="brtset" />	
								</Col>
							</Row>
						</Col>
                    </Row>
                     {/* 第11行 */}
					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									 <Label itext="编号" trn="brtset" />	
								</Col>
                                <Col span={14} >
                                    <InputItem InputProps={bind("pts2_ref")}  maxLength={16}  desp="参考号" path="/brdgrp/prb/pts/ref" />
								</Col>
							</Row>
						</Col>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									 <Label itext="客户英文名称" trn="brtset" />	
								</Col>
                                <Col span={14} >
									<InputItem InputProps={bind("pts2_nam")}  maxLength={100}  desp="客户英文名称" path="/brdgrp/prb/pts/nam" />
								</Col>
							</Row>
						</Col>
                    </Row>
                    {/* 第12行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									 <Label itext="单据类型" trn="brtset" />	
								</Col>
                                <Col span={14} >
									<SelectItem InputProps={bind("docflg")}   desp="Usance, Sight or Mixed" path="/brdgrp/rec/docflg"/>
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据状态" trn="brtset" />	
								</Col>
                                <Col span={14} >
                                    <SelectItem InputProps={bind("docsta")} code={CodeTable.docsta}  desp="Document Set Status" path="/brdgrp/rec/docsta"/>
								</Col>
							</Row>
						</Col>
                    </Row>
			{/* brtp/brthdr */}
				{/* 第13行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									 <Label itext="融资标志" trn="brtset" />	
								</Col>
                                <Col span={14} >
								<CheckboxItem InputProps={bind("trtcre_crefinflg")}  desp="融资标志" path="/trtcre/crefinflg" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Amount Settled" trn="brtset" />	
								</Col>
                                <Col span={6} >
									<InputItem InputProps={bind("setmod_doccur")}  maxLength={3}  desp="document currency" path="/setmod/doccur" />
								</Col>
								<Col span={7}  offset={1}>
									<InputItem InputProps={bind("setmod_docamt")}   desp="document amount" path="/setmod/docamt" />
								</Col>
							</Row>
						</Col>
                    </Row>
					{/* 第14行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									 {/* <Label itext="Unpaid by Applicant" trn="brtset" />	 */}
									 <Label itext="Unpaid by Applt" trn="brtset" />		 
								</Col>
                                <Col span={14} >
									<CheckboxItem InputProps={bind("paypsb")}  desp="Unpaid by Applicant" path="/paypsb" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* <Label itext="Free of Payment Flag" trn="brtset" />	 */}
									<Label itext="Fr of Pay Flag" trn="brtset" />	
								</Col>
                                <Col span={14} >
									<CheckboxItem InputProps={bind("frepayflg")}  desp="Free of Payment Flag" path="/brdgrp/rec/frepayflg" />
								</Col>
							</Row>
						</Col>
                    </Row>
					{/* 第15行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									 {/* <Label itext="Close Flag" trn="brtset" />	 */}
									 <Label itext="Close Flag" trn="brtset" />		 
								</Col>
                                <Col span={14} >
									<CheckboxItem InputProps={bind("mtabut_clsflg")}  desp="Close Flag" path="/mtabut/clsflg" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Reduction Amt." trn="brtset" />	
								</Col>
                                <Col span={6} >
									<InputItem InputProps={bind("setmod_redamt")}   desp="Reduction Amount" path="/setmod/redamt" />
								</Col>
								<Col span={7} offset={1} >
									<InputItem InputProps={bind("setmod_setamt")}   desp="Reduced Amount to settle" path="/setmod/setamt" />
								</Col>
							</Row>
						</Col>
                    </Row>
					{/* 第16行 */}
					<Row>
                        <Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* <Label itext="Narrative of incoming MT754, tag :77A:" trn="brtset" />		  */}
									<Label itext="Narrative :77A:" trn="brtset" />		 
								</Col>
                                <Col span={14} >
									<TextAreaItem InputProps={bind("nar754")} desp="Narrative :77A:" path="/nar754"/>
								</Col>
							</Row>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="单据金额" trn="brtset" />			 
								</Col>
                                <Col span={6} >
									<SelectItem InputProps={bind("opn2_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/opn2/cur"/>
								</Col>
								<Col span={7} offset={1}>
									<InputItem InputProps={bind("aamset_utlamt")}   desp="Doc. Amount utilized/settled" path="/aamset/utlamt" />
								</Col>
							</Row>
							<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="附加金额" trn="brtset" />	
								</Col>
                                <Col span={6} >
									<SelectItem InputProps={bind("opn2_cur")} code={CodeTable.curtxt}  desp="Currency" path="/brdgrp/cbs/opn2/cur"/>
								</Col>
								<Col span={7} offset={1} >
									<InputItem InputProps={bind("aamset_utlamt2")}   desp="Add. Amount utilized/settled" path="/aamset/utlamt2" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
						<Row className="row">
								<Col span={5} offset={2}>
									<Label itext="Presented by" trn="brtset" />		 
								</Col>
                                <Col span={14} >
									<SelectItem InputProps={bind("docprbrol")}   desp="Presented by" path="/brdgrp/rec/docprbrol"/>
								</Col>
							</Row>
							<Row className="row">
								<Col >
                                    <Ptspta2 model={this.model} argArr={{ desc: "客户编号",desc1:"SWIFT地址",prefix: 'pts2', url: 'brtset/prbp_sel', flg: 'C', datakey: '\\brtp\\prbp\\ptslst' }} formBlur={this.formBlur}/>
                                </Col>
							</Row>
						</Col>
                    </Row>
					
	
	

	

	
	{/* <Label itext="Reduced Amt. Settled" trn="brtset" />	 */}

	

	

	

	

	
	{/* <InputItem InputProps={bind("pts2_extkey")}  maxLength={16}  desp="客户编号" path="/brdgrp/prb/pts/extkey" />
	<Button  type="primary" icon="search" onClick={this.onPrbp_sel} desp="查询" path="/brtp/prbp/sel">
		<Label   itext="查询"/>
	</Button>
	<TextAreaItem InputProps={bind("pts2_adrblk")} desp="SWIFT地址" path="/brdgrp/prb/pts/adrblk"/>
	<Button  type="primary"  onClick={this.onLiaall_astlia} desp="表外加载" path="/liaall/astlia">
		<Label   itext="表外加载"/>
	</Button> */}

			{/* 底部按钮 */}
		<BottomBtn _this={this} />
	
		</div>
		)
	}
}
