import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,BottomBtn,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table} from '@/components/Common-Library'
import Api from '@/service/api'
import mGetcrq from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { Row, Col } from 'antd'
import { action, observable,runInAction } from 'mobx'
import Business from '@/views/Public/Business'
import Ptspta2 from '@/views/Public/Ptspta2'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class GetcrqScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'getcrq'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mGetcrq()    
        this.bind = Bind.bind(this)
    }
	
	async componentWillMount() 
	{
		/*
		*添加初始化代码
		*/
		const rtnmsg = await Api.post('getcrq/init',{data:this.model})
		if(rtnmsg.retcod == SUCCESS)
		{
           const {data} = rtnmsg
           runInAction(()=>{
                Object.assign(this.model,data)
           }) 
        }
		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor && this.model.openMonitor() //开启校验	
	}
    componentWillUnmount()
    {
        this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    onGetref= ()=>{
        this.formBlur=true  //已触发表单提交处理
        Validator.validate(this.model,this.model.descriptor,async(errors,values)=>{
                if(errors)
                    return 
                const rtnmsg = await Api.post('getcrq/getref',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'数据提交成功!'})
                    
                }
                else
                {
                	Notification.error({message:'服务端请求失败!'})
                }
                //余下逻辑处理
                    
        })
    }
    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
        	<div className="transPage">
				 <Business  wrappedComponentRef={ref => (this.com = ref)} page={this} steps={this.props.steps} extra={this.props.extra}  model={this.model} />
				{/* 第一行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Guarantee" trn="getcrq" />	
							</Col>
							<Col span={14} >
								<InputItem InputProps={bind("ownref1")}  maxLength={16}  desp="Reference" path="/gidgrp/rec/ownref" />
							</Col>							
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Open Amount" trn="getcrq" />	
							</Col>
							<Col span={4} >
								<InputItem InputProps={bind("opn11_cur")}  maxLength={3}  desp="Currency" path="/gidgrp/cbs/opn1/cur" />
							</Col>
							<Col span={4} offset={1}>
								<InputItem InputProps={bind("opn11_cur")}  maxLength={3}  desp="Currency" path="/gidgrp/cbs/opn1/cur" />
							</Col>
							<Col span={4} offset={1}>
								<InputItem InputProps={bind("opn11_amt")}   desp="Balance" path="/gidgrp/cbs/opn1/amt" />
							</Col>
						</Row>
					</Col>
				</Row>

				{/* 第二行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="expfldlab" trn="getcrq" />	
							</Col>						
							{/* <Col >
								<Label value={this.model.gctp_expfldlab}   desp="Label for Field Validity" path="/gctp/expfldlab" />	
							</Col>
							<Col >
								<Label value={this.model.gctp_explab}   desp="Label unlimited Validity" path="/gctp/explab" />	
							</Col> */}
							<Col span={14} >
								<DatePickerItem InputProps={bind("expdat")}  desp="Valid until" path="/gidgrp/rec/expdat" />	
							</Col>									
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Name" trn="getcrq" />	
							</Col>
							<Col span={14} >
								<InputItem InputProps={bind("nam")}  maxLength={40}  desp="Externally Displayed Name to Identify the Contract" path="/gcdgrp/rec/nam" />
							</Col>					
						</Row>
					</Col>
				</Row>

				{/* 第三行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Claim Number" trn="getcrq" />		
							</Col>
							<Col span={11} >
								<InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/gcdgrp/rec/ownref" />
							</Col>
							<Col span={2} offset={1}>
							<Button  type="primary"  onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
								<Label   itext="获取"/>
							</Button>
							</Col>							
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Applicant Ref." trn="getcrq" />	
							</Col>
							<Col span={14} >
								<InputItem InputProps={bind("pts_ref")}  maxLength={16}  desp="参考号" path="/gcdgrp/apl/pts/ref" />
							</Col>							
						</Row>
					</Col>
				</Row>

				{/* 第四行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Amount Claimed" trn="getcrq" />		
							</Col>
							<Col span={6} >
								<SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/gcdgrp/cbs/max/cur"/>
							</Col>	
							<Col span={7} offset={1}>
								<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/gcdgrp/cbs/max/amt" />
							</Col>
												
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Add. Amount" trn="getcrq" />		
							</Col>	
							<Col span={1} >
								<CheckboxItem InputProps={bind("gctp_adaflg")}  desp="Add. Amount" path="/gctp/adaflg" />
							</Col>
							
														
						</Row>
					</Col>
					
				</Row>

				{/* 第五行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Open Amount" trn="getcrq" />		
							</Col>
							<Col span={6} >
								<SelectItem InputProps={bind("opn1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/gcdgrp/cbs/opn1/cur"/>
							</Col>	
							<Col span={7} offset={1}>
								<InputItem InputProps={bind("opn1_amt")}   desp="Balance" path="/gcdgrp/cbs/opn1/amt" />
							</Col>									
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
						
							<Col span={5} offset={2}>
								<Label itext="客户英文名称" trn="getcrq" />		
							</Col>						
							<Col  span={14} >
								<InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/gcdgrp/apl/pts/nam" />
							</Col>
						
							{/* <Col  offset={7} span={17}>
								<Label value={this.model.gctp_aplmullab}   desp="Label, that is set, if there are multiple applicants" path="/gctp/aplmullab" />
							</Col>	 */}
						</Row>		
					</Col>						
				</Row>
				
				{/* 第六行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Type of Undertaking" trn="getcrq" />		
							</Col>
							<Col span={14} >
								<SelectItem InputProps={bind("gartyp")} code={CodeTable.typgar}  desp="Type of Undertaking" path="/gidgrp/rec/gartyp"/>
							</Col>				
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Beneficiary Ref." trn="getcrq" />	
							</Col>
							<Col span={14} >
								<InputItem InputProps={bind("pts1_ref")}  maxLength={16}  desp="参考号" path="/gcdgrp/ben/pts/ref" />
							</Col>							
						</Row>
					</Col>
				</Row>	

				{/* 第七行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Date of Claim" trn="getcrq" />	
							</Col>
							<Col span={14} >
								<DatePickerItem InputProps={bind("clmdat")}  desp="Date of Claim" path="/gcdgrp/rec/clmdat" />
							</Col>							
						</Row>
					</Col>
					<Col span={12}>		
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="客户英文名称" trn="getcrq" />	
							</Col>				
							<Col  span={14}>
								<InputItem InputProps={bind("pts_nam")}  maxLength={100}  desp="客户英文名称" path="/gcdgrp/apl/pts/nam" />
							</Col>		
						</Row>
					</Col>
				</Row>		

				{/* 第九行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Amount Claimed" trn="getcrq" />	
							</Col>						
							<Col span={6} >
								<InputItem InputProps={bind("max_cur")}  maxLength={3}  desp="Currency" path="/gcdgrp/cbs/max/cur" />	
							</Col>
							<Col span={7} offset={1}>
								<InputItem InputProps={bind("max_amt")}   desp="Balance" path="/gcdgrp/cbs/max/amt" />	
							</Col>							
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Presented by" trn="getcrq" />	
							</Col>
							<Col span={14} >
								<SelectItem InputProps={bind("docprbrol")}   desp="Presented by" path="/gcdgrp/rec/docprbrol"/>
							</Col>					
						</Row>
					</Col>
				</Row>

				{/* 第10行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="附加金额" trn="getcrq" />		
							</Col>						
							<Col span={6}>
								<SelectItem InputProps={bind("opn2_cur")} code={CodeTable.curtxt}  desp="Currency" path="/gcdgrp/cbs/opn2/cur"/>	
							</Col>
							<Col span={7} offset={1}>
								<InputItem InputProps={bind("max2_amt")}   desp="Balance" path="/gcdgrp/cbs/max2/amt" />	
							</Col>								
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Reference " trn="getcrq" />	
							</Col>
							<Col span={14} >
								<InputItem InputProps={bind("pts3_ref")}  maxLength={16}  desp="参考号" path="/gcdgrp/prb/pts/ref" />
							</Col>					
						</Row>
					</Col>
				</Row>

				{/* 第11行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Liability until" trn="getcrq" />		
							</Col>
							<Col span={14} >
								<DatePickerItem InputProps={bind("liadat")}  desp="Liability until" path="/gidgrp/rec/liadat" />
							</Col>
														
						</Row>
					</Col>
					<Col span={12}>		
					<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Further Processing" trn="getcrq" />			
							</Col>
							<Col span={14} >
								<SelectItem InputProps={bind("nxtflg")} code={CodeTable.nxtflg}  desp="Further Processing" path="/nxtflg"/>
							</Col>															
						</Row>
					</Col>
				</Row>		
				{/* 第13行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Text of Claim" trn="getcrq" />			
							</Col>
							<Col span={14} >
								<TextAreaItem InputProps={bind("clmtxt")} desp="Text of claim" path="/clmtxt"/>
							</Col>														
						</Row>
						
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Validity Requested" trn="getcrq" />				
							</Col>
							<Col span={14} >
								<DatePickerItem InputProps={bind("newexpdat")}  desp="Validity Requested" path="/gcdgrp/rec/newexpdat" />
							</Col>														
						</Row>
				
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Payer" trn="getcrq" />			
							</Col>
							<Col span={14} >
								<SelectItem InputProps={bind("payrol")}   desp="Payer" path="/gcdgrp/rec/payrol"/>
							</Col>
						</Row>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label itext="Extend or Pay" trn="getcrq" />			
							</Col>
							<Col span={14} >
								<CheckboxItem InputProps={bind("extpay")}  desp="Extend or Pay" path="/extpay" />	
							</Col>
						</Row>		
					</Col>						
				</Row>
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col >
								<Ptspta2 model={this.model} argArr={{ desc: "客户编号",desc1:"SWIFT地址",prefix: 'pts2', url: 'getcrq/othp_sel', flg: 'C', datakey: '\\gitp\\othp\\ptslst' }} formBlur={this.formBlur}/>
							</Col>						
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col >
								<Ptspta2 model={this.model} argArr={{ desc: "客户编号",desc1:"SWIFT地址",prefix: 'pts3', url: 'getcrq/prbp_sel', flg: 'C', datakey: '\\gitp\\prbp\\ptslst' }} formBlur={this.formBlur}/>
							</Col>					
						</Row>
					</Col>
				</Row>
						
				 {/* 第14行 */}

				<BottomBtn _this={this} />
		</div>
		)
	}
}
