import React,{Component,Fragment} from 'react'
import PropTypes from 'prop-types'
import {Page,Validator,Notification,FormItem,DatePickerItem,TextAreaItem,CheckboxItem,Checkbox,
    InputItem,Input,Bind,SelectItem,Button,Label,Image,Table,BottomBtn} from '@/components/Common-Library'
import Api from '@/service/api'
import mLitame from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable,runInAction } from 'mobx'
import { Row, Col} from 'antd';
import Ptspta2 from '@/views/Public/Ptspta2'
import Business from '@/views/Public/Business'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class BasicScreen extends Page
{
    static childContextTypes = {
        trn: PropTypes.string,
    }
    getChildContext () {
        return {trn:'litame'}
    }
    
    
    @observable
    formBlur=false

    constructor(props)
    {
        super(props)
        this.model = new mLitame()    
        this.bind = Bind.bind(this)
    }
    

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
             
        return (
            
           <div style={{ position: 'relative' }}>
                <Business wrappedComponentRef={ref => (this.com = ref)} steps={this.props.steps} extra={this.props.extra} model={this.model} />
                {/*第一行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Reference*/}
                                <Label itext="Reference"/>
                            </Col>
                            <Col span={11}>
                                <InputItem InputProps={bind("ownref")}  maxLength={16}  desp="Reference" path="/lidgrp/rec/ownref" />
                            </Col>
                            <Col span={2} offset={1}>
                                <Button  type="primary"  onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
                                    <Label   itext="获取"/>
                                </Button>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Name"/>
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("nam")}  maxLength={140}  desp="Externally Displayed Name to Identify the Contract" path="/lidgrp/rec/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                {/*第二行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*From of L/C*/}
                                <Label itext="From of L/C"/>
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("lcrtyp")} code={CodeTable.lcrtyp}  desp="Form of Documentary Credit" path="/lidgrp/rec/lcrtyp"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*responsible user*/}
                            <Label itext="Responsiblr User"/>
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("usr_nam")}  maxLength={8}  desp="用户ID" path="/sysmod/usr/nam" />
                            </Col>
                        </Row>
                    </Col>
                </Row>

                {/*第三行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="ReservedContract"/>
                            </Col>
                            <Col span={14}>
                                <CheckboxItem InputProps={bind("resflg")}  desp="Reserved Contract" path="/lidgrp/rec/resflg" />
                            </Col>
                        </Row>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Nominal Amount*/}
                                <Label itext="Nominal Amount"/>
                            </Col>
                            <Col span={6}>
                                <SelectItem InputProps={bind("nom1_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/nom1/cur"/>
                            </Col>
                            <Col span={7} offset={1}> 
                                <InputItem InputProps={bind("nom1_amt")}   desp="Balance" path="/lidgrp/cbs/nom1/amt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Ptspta2  model={this.model} argArr={{ desc: "客户编号",desc1:"SWIFT地址", prefix: 'pts1', url: 'litame/aplp_ptysel', flg: 'C', datakey: '\\litp\\aplp\\ptslst' }} />
                    </Col>
                </Row>
                {/*第四行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Add.Amount"/>
                            </Col>
                            <Col span={14}>
                                <CheckboxItem InputProps={bind("aammod_addamtflg")}  desp="Add. Amount" path="/litp/aamp/aammod/addamtflg" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Amount Tolerance +/-*/}
                                <Label itext="Amount Tolerance +/-"/>
                            </Col>
                            <Col span={6}>
                                <InputItem InputProps={bind("nomtop")}   desp="Amount Tolerance - Positive" path="/lidgrp/rec/nomtop" />
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("nomton")}   desp="Amount Tolerance - Negative" path="/lidgrp/rec/nomton" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                {/*第五行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Amount Specification*/}
                            <Label itext="Amount Specification"/>
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("nomspc")} code={CodeTable.nomspc}  desp="Amount Specification" path="/lidgrp/rec/nomspc"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Maximum Amount*/}
                                <Label itext="Maximum Amount"/>
                            </Col>
                            <Col span={6}>
                            <SelectItem InputProps={bind("max_cur")} code={CodeTable.curtxt}  desp="Currency" path="/lidgrp/cbs/max/cur"/>
                            </Col>
                            <Col span={7} offset={1}>
                                <InputItem InputProps={bind("max_amt")}   desp="Balance" path="/lidgrp/cbs/max/amt" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                {/*第七行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*L/C Issued on*/}
                                <Label itext="L/C Issued on"/>
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("opndat")}  desp="Date L/C Opened/Issued" path="/lidgrp/rec/opndat" />
                            </Col>
                        </Row>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Date Pre-advised*/}
                                <Label itext="Date Pre-advised"/>
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("preadvdt")}  desp="Date Pre-advised" path="/lidgrp/rec/preadvdt" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Ptspta2  model={this.model} argArr={{ desc: "Advising bank",desc1:"SWIFT地址", prefix: 'pts2', url: 'litame/advp_ptysel', flg: 'B', datakey: '\\litp\\advp\\ptslst' }} />
                    </Col>
                </Row>
                {/*第九行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Latest Shipment Date*/}
                                <Label itext="Latest Shipment Date"/>
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("shpdat")}  desp="Shipment Date" path="/lidgrp/rec/shpdat" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*L/C Expiring on*/}
                            <Label itext="L/C Expiring on"/>
                            </Col>
                            <Col span={14}>
                                <DatePickerItem InputProps={bind("expdat")}  desp="Date of Expiry" path="/lidgrp/rec/expdat" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
                {/*第十一行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*in (Place)/counter*/}
                                <Label itext="in (Place)/counter"/>
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("expplc")}  maxLength={29}  desp="Place of Expiry" path="/lidgrp/rec/expplc" />
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Partial Shipm*/}
                                <Label itext="Partial Shipm"/>
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("shppar")} code={CodeTable.shppar}  desp="Partial Shipment" path="/lidgrp/rec/shppar"/>
                            </Col>
                        </Row>
                    </Col>
                </Row>
                
                {/*第十三行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Transshipment*/}
                                <Label itext="Transshipment"/>
                            </Col>
                            <Col span={14}>
                            <SelectItem InputProps={bind("shptrs")} code={CodeTable.shppar}  desp="Transshipment" path="/lidgrp/rec/shptrs"/> 
                            </Col>
                        </Row>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Applicable Rule*/}
                                <Label itext="Applicable Rules"/>
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("apprul")} code={CodeTable.apprul}  desp="Applicable Rules" path="/lidgrp/rec/apprul"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Ptspta2  model={this.model} argArr={{ desc: "Beneficiary",desc1:"SWIFT地址", prefix: 'pts3', url: 'litame/benp_ptysel', flg: 'C', datakey: '\\litp\\benp\\ptslst' }} />
                    </Col>
                </Row>
                
                {/*第十五行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Other applicable Rules*/}
                                <Label itext="Other applicable Rules"/>
                            </Col>
                            <Col span={14}>
                                <InputItem InputProps={bind("apprultxt")}  maxLength={35}  desp="Other Applicable Rules" path="/lidgrp/rec/apprultxt" />   
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Reimbursement"/>
                            </Col>
                            <Col span={14}>
                            <CheckboxItem InputProps={bind("rmbflg")}  desp="Reimbursement Information" path="/lidgrp/rec/rmbflg" />
                            </Col>
                        </Row>
                    </Col>
                </Row>
            {/*第十六行*/}
                <Row>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                {/*Confirm Instruction*/}
                                <Label itext="Confirm Instruction"/>
                            </Col>
                            <Col span={14}>
                                <SelectItem InputProps={bind("cnfdet")} code={CodeTable.cnfflg}  desp="Confirmation Instructions" path="/lidgrp/rec/cnfdet"/>
                            </Col>
                        </Row>
                    </Col>
                    <Col span={12}>
                        <Row className="row">
                            <Col span={5} offset={2}>
                                <Label itext="Revolving L/C"/>
                            </Col>
                            <Col span={14}>
                                <CheckboxItem InputProps={bind("revflg")}  desp="Revolving Flag" path="/lidgrp/rec/revflg" /> 
                            </Col>
                        </Row>
                    </Col>
                </Row>
                <BottomBtn _this={this} />
		</div>
		)
	}
}
